@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 from typing import Optional
 
 import pytorch_lightning as pl
@@ -13,6 +14,7 @@ from .modelchoice import ModelChoice
 
 
 @ModelChoice.register_arguments(call_name="pl_seq2seq")
+@dataclass(unsafe_hash=True)
 class Seq2SeqArguments(_ABCDataClass):
     src_vocab_size: int = 112
     tgt_vocab_size: int = 112
@@ -27,7 +29,12 @@ class Seq2SeqArguments(_ABCDataClass):
     max_seq_len: Optional[int] = None
 
 
-@ModelChoice.register_choice(call_name="pl_seq2seq", author="Peter Hartog", github_handle="PeterHartog", credit_type=CreditType.NONE)
+@ModelChoice.register_choice(
+    call_name="pl_seq2seq",
+    author="Peter Hartog",
+    github_handle="PeterHartog",
+    credit_type=CreditType.NONE,
+)
 class Seq2Seq(pl.LightningModule):
     def __init__(self, model_args: Seq2SeqArguments) -> None:
         super().__init__()
